@@ -64,7 +64,6 @@ import Network.Gitit.ContentTransformer (showRawPage, showFileAsText, showPage,
         exportPage, showHighlightedSource, preview, applyPreCommitPlugins)
 import Network.Gitit.Page (readCategories)
 import Control.Exception (throwIO, catch, try)
-import System.Time
 import System.FilePath
 import Prelude hiding (catch)
 import Network.Gitit.State
@@ -79,6 +78,7 @@ import qualified Data.ByteString.Lazy as B
 import qualified Data.ByteString as S
 import Network.HTTP (urlEncodeVars)
 import Data.Time (getCurrentTime, addUTCTime)
+import Data.Time.Clock (diffUTCTime, UTCTime(..))
 import Data.FileStore
 import System.Log.Logger (logM, Priority(..))
 
@@ -111,15 +111,15 @@ randomPage :: Handler
 randomPage = do
   fs <- getFileStore
   files <- liftIO $ index fs
-  let pages = map dropExtension $
-                filter (\f -> isPageFile f && not (isDiscussPageFile f)) files
   base' <- getWikiBase
+  let pages = map dropExtension $
+              filter (\f -> isPageFile f && not (isDiscussPageFile f)) files
   if null pages
      then error "No pages found!"
      else do
-       TOD _ picosecs <- liftIO getClockTime
+       secs <- liftIO (fmap utctDayTime getCurrentTime)
        let newPage = pages !!
-                     ((fromIntegral picosecs `div` 1000000) `mod` length pages)
+                     (truncate (secs * 1000000) `mod` length pages)
        seeOther (base' ++ urlForPage newPage) $ toResponse $
          p << "Redirecting to a random page"
 
@@ -460,7 +460,7 @@ showDiff file page params = do
        Left e         -> liftIO $ throwIO e
        Right htmlDiff -> formattedPage defaultPageLayout{
                                           pgPageName = page,
-                                          pgRevision = from',
+                                          pgRevision = from' `mplus` to,
                                           pgMessages = pMessages params,
                                           pgTabs = DiffTab :
                                                    pgTabs defaultPageLayout,
@@ -472,9 +472,9 @@ getDiff :: FileStore -> FilePath -> Maybe RevisionId -> Maybe RevisionId
         -> IO Html
 getDiff fs file from to = do
   rawDiff <- diff fs file from to
-  let diffLineToHtml (B, xs) = thespan << unlines xs
-      diffLineToHtml (F, xs) = thespan ! [theclass "deleted"] << unlines xs
-      diffLineToHtml (S, xs) = thespan ! [theclass "added"]   << unlines xs
+  let diffLineToHtml (Both xs _) = thespan << unlines xs
+      diffLineToHtml (First xs) = thespan ! [theclass "deleted"] << unlines xs
+      diffLineToHtml (Second xs) = thespan ! [theclass "added"]  << unlines xs
   return $ h2 ! [theclass "revision"] <<
              ("Changes from " ++ fromMaybe "beginning" from ++
               " to " ++ fromMaybe "current" to) +++
@@ -541,6 +541,7 @@ editPage' params = do
   let pgScripts'' = case mathMethod cfg of
        JsMathScript -> "jsMath/easy/load.js" : pgScripts'
        MathML       -> "MathMLinHTML.js" : pgScripts'
+       MathJax url  -> url : pgScripts'
        _            -> pgScripts'
   formattedPage defaultPageLayout{
                   pgPageName = page,
@@ -704,7 +705,7 @@ categoryPage = do
              forM pages $ \f -> do
                categories <- liftIO $ readCategories $ repoPath </> f
                return $ if category `elem` categories
-                           then Just $ dropExtension f
+                           then Just f
                            else Nothing
   base' <- getWikiBase
   let toMatchListItem file = li <<
@@ -768,9 +769,8 @@ feedHandler = do
   let file = (path' `orIfNull` "_site") <.> "feed"
   let mbPath = if null path' then Nothing else Just path'
   -- first, check for a cached version that is recent enough
-  now <- liftIO $ getClockTime
-  let isRecentEnough t = normalizeTimeDiff (diffClockTimes now t) <
-                         normalizeTimeDiff (noTimeDiff{tdMin = fromIntegral $ feedRefreshTime cfg})
+  now <- liftIO getCurrentTime
+  let isRecentEnough t = truncate (diffUTCTime now t) < 60 * feedRefreshTime cfg
   mbCached <- lookupCache file
   case mbCached of
        Just (modtime, contents) | isRecentEnough modtime -> do
