@@ -90,6 +90,8 @@ data Config = Config {
   maxUploadSize        :: Integer,
   -- | Max size of page uploads
   maxPageSize          :: Integer,
+  -- | IP address to bind to
+  address              :: String,
   -- | Port number to serve content on
   portNumber           :: Int,
   -- | Print debug info to the console?
@@ -300,7 +302,7 @@ instance FromReqURI [String] where
 
 instance FromData Params where
      fromData = do
-         let look' = liftM fromEntities . look
+         let look' = look
          un <- look' "username"       `mplus` return ""
          pw <- look' "password"       `mplus` return ""
          p2 <- look' "password2"      `mplus` return ""
@@ -316,7 +318,7 @@ instance FromData Params where
          pa <- look' "patterns"       `mplus` return ""
          gt <- look' "gotopage"       `mplus` return ""
          ft <- look' "filetodelete"   `mplus` return ""
-         me <- lookRead "messages"   `mplus` return []
+         me <- looks "message"
          fm <- liftM Just (look' "from") `mplus` return Nothing
          to <- liftM Just (look' "to")   `mplus` return Nothing
          et <- liftM (Just . filter (/='\r')) (look' "editedText")
