@@ -10,6 +10,12 @@ function updatePreviewPane() {
         if (typeof(convert) == 'function') { convert(); }
         // Process any mathematics if we're using jsMath
         if (typeof(jsMath) == 'object')    { jsMath.ProcessBeforeShowing(); }
+        // Process any mathematics if we're using MathJax
+        if (typeof(window.MathJax) == 'object') {
+          // http://docs.mathjax.org/en/latest/typeset.html
+          var math = document.getElementById("MathExample");
+          MathJax.Hub.Queue(["Typeset",MathJax.Hub,math]);
+        }
       },
       "html");
 
@@ -18,5 +24,6 @@ function updatePreviewPane() {
 };
 $(document).ready(function(){
     $("#previewButton").show();
-  });
+    $("#editedText").focus();
+});
 
